﻿using Infragistics.Windows.DataPresenter;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace HideShowFieldsBasedOnCellValue
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            DataContext = new List<Data>
            {
               new Data
               { 
                   ID = 1,
                   Name = "item 1",
                   NumOfColumns = 3,
                   SubAllocation1 = 12,
                   SubAllocation2 = 1,
                   SubAllocation3 = 5,
                   SubAllocation4 = 6,
                   SubAllocation5 = 78,
                   SubAllocation6 = 1,
                   SubAllocation7 = 23,
                   SubAllocation8 = 12,
                   SubAllocation9 = 3,
                   SubAllocation10 = 2,
                   Children = new List<ChildData>
                   {
                       new ChildData
                       {
                           Allocation = "child 1",
                           Description = "some",
                           Lob = 12,
                           SubAllocation1 = 12,
                           SubAllocation2 = 1,
                           SubAllocation3 = 5,
                           SubAllocation4 = 6,
                           SubAllocation5 = 78,
                           SubAllocation6 = 1,
                           SubAllocation7 = 23,
                           SubAllocation8 = 12,
                           SubAllocation9 = 3,
                           SubAllocation10 = 2,                           
                       }
                   }
               }
            };
          
        }

        private void XamDataGrid_FieldLayoutInitialized(object sender, Infragistics.Windows.DataPresenter.Events.FieldLayoutInitializedEventArgs e)
        {
            int nOfCols = (int)((sender as XamDataGrid).Records[0] as DataRecord).Cells["NumOfColumns"].Value;

            UpdateFieldVisibility(e.FieldLayout, nOfCols);
        }

        private void XamDataGrid_EditModeEnded(object sender, Infragistics.Windows.DataPresenter.Events.EditModeEndedEventArgs e)
        {
            if (e.Cell.Field.Name.Equals("NumOfColumns"))
            {
                foreach (FieldLayout fl in e.Cell.Field.Owner.DataPresenter.FieldLayouts)
                    UpdateFieldVisibility(fl, (int)e.Cell.Value);
            }
        }


        private void UpdateFieldVisibility(FieldLayout fieldLayout, int nOfCols)
        {
            List<Field> fields = fieldLayout.Fields.Where(f => f.Name.Contains("SubAllocation")).ToList();

            foreach (var item in fields)
                    item.Visibility = System.Windows.Visibility.Visible;

            if (nOfCols <= fields.Count)
            {
                for (int i = nOfCols; i < fields.Count; i++)
                {
                    fields[i].Visibility = System.Windows.Visibility.Collapsed;
                }
            }
            else
            {
                foreach (var item in fields)
                    item.Visibility = System.Windows.Visibility.Collapsed;
            }
        }


        private void XamDataGrid_RecordAdded(object sender, Infragistics.Windows.DataPresenter.Events.RecordAddedEventArgs e)
        {
            ChildData items = e.Record.DataItem as ChildData;

            if (items != null)
            {
                items.Description = "description1";

            }
        } 
    }

    public class Data
    {
        public int ID { get; set; }
        public string Name { get; set; }

        public int NumOfColumns { get; set; }

        public int SubAllocation1 { get; set; }
        public int SubAllocation2 { get; set; }
        public int SubAllocation3 { get; set; }
        public int SubAllocation4 { get; set; }
        public int SubAllocation5 { get; set; }
        public int SubAllocation6 { get; set; }
        public int SubAllocation7 { get; set; }
        public int SubAllocation8 { get; set; }
        public int SubAllocation9 { get; set; }
        public int SubAllocation10 { get; set; }

        public List<ChildData> Children { get; set; }
    }

    public class ChildData
    {
        public int Lob { get; set; }
        public string Allocation { get; set; }
        public string Description { get; set; }

        public int SubAllocation1 { get; set; }
        public int SubAllocation2 { get; set; }
        public int SubAllocation3 { get; set; }
        public int SubAllocation4 { get; set; }
        public int SubAllocation5 { get; set; }
        public int SubAllocation6 { get; set; }
        public int SubAllocation7 { get; set; }
        public int SubAllocation8 { get; set; }
        public int SubAllocation9 { get; set; }
        public int SubAllocation10 { get; set; }
    }
}
